==> tekton-model-triggers-v1alpha1-6.6.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/WebhookInterceptorFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import io.fabric8.tekton.pipeline.v1beta1.Param;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface WebhookInterceptorFluent<A extends WebhookInterceptorFluent<A>> extends Fluent<A>{
  public A addToHeader(Integer index,Param item);
  public A setToHeader(Integer index,Param item);
  public A addToHeader(io.fabric8.tekton.pipeline.v1beta1.Param... items);
  public A addAllToHeader(Collection<Param> items);
  public A removeFromHeader(io.fabric8.tekton.pipeline.v1beta1.Param... items);
  public A removeAllFromHeader(Collection<Param> items);
  public List<Param> getHeader();
  public Param getHeader(Integer index);
  public Param getFirstHeader();
  public Param getLastHeader();
  public Param getMatchingHeader(Predicate<Param> predicate);
  public Boolean hasMatchingHeader(Predicate<Param> predicate);
  public A withHeader(List<Param> header);
  public A withHeader(io.fabric8.tekton.pipeline.v1beta1.Param... header);
  public Boolean hasHeader();
  
  /**
   * This method has been deprecated, please use method buildObjectRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getObjectRef();
  public ObjectReference buildObjectRef();
  public A withObjectRef(ObjectReference objectRef);
  public Boolean hasObjectRef();
  public WebhookInterceptorFluent.ObjectRefNested<A> withNewObjectRef();
  public WebhookInterceptorFluent.ObjectRefNested<A> withNewObjectRefLike(ObjectReference item);
  public WebhookInterceptorFluent.ObjectRefNested<A> editObjectRef();
  public WebhookInterceptorFluent.ObjectRefNested<A> editOrNewObjectRef();
  public WebhookInterceptorFluent.ObjectRefNested<A> editOrNewObjectRefLike(ObjectReference item);
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public interface ObjectRefNested<N> extends Nested<N>,ObjectReferenceFluent<WebhookInterceptorFluent.ObjectRefNested<N>>{
    public N and();
    public N endObjectRef();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/WebhookInterceptorFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluent;
import java.lang.Deprecated;
import io.fabric8.tekton.pipeline.v1beta1.Param;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface WebhookInterceptorFluent<A extends WebhookInterceptorFluent<A>> extends Fluent<A>{
  public A addToHeader(int index,Param item);
  public A setToHeader(int index,Param item);
  public A addToHeader(io.fabric8.tekton.pipeline.v1beta1.Param... items);
  public A addAllToHeader(Collection<Param> items);
  public A removeFromHeader(io.fabric8.tekton.pipeline.v1beta1.Param... items);
  public A removeAllFromHeader(Collection<Param> items);
  public List<Param> getHeader();
  public Param getHeader(int index);
  public Param getFirstHeader();
  public Param getLastHeader();
  public Param getMatchingHeader(Predicate<Param> predicate);
  public Boolean hasMatchingHeader(Predicate<Param> predicate);
  public A withHeader(List<Param> header);
  public A withHeader(io.fabric8.tekton.pipeline.v1beta1.Param... header);
  public Boolean hasHeader();
  
  /**
   * This method has been deprecated, please use method buildObjectRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectReference getObjectRef();
  public ObjectReference buildObjectRef();
  public A withObjectRef(ObjectReference objectRef);
  public Boolean hasObjectRef();
  public WebhookInterceptorFluent.ObjectRefNested<A> withNewObjectRef();
  public WebhookInterceptorFluent.ObjectRefNested<A> withNewObjectRefLike(ObjectReference item);
  public WebhookInterceptorFluent.ObjectRefNested<A> editObjectRef();
  public WebhookInterceptorFluent.ObjectRefNested<A> editOrNewObjectRef();
  public WebhookInterceptorFluent.ObjectRefNested<A> editOrNewObjectRefLike(ObjectReference item);
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public interface ObjectRefNested<N> extends Nested<N>,ObjectReferenceFluent<WebhookInterceptorFluent.ObjectRefNested<N>>{
    public N and();
    public N endObjectRef();
    
  }
  
}
